************
Installation
************


Installing Spyderwebb
=====================


The easiest way to install |Spyderwebb| is using pip:

To get the very lastest version:

.. code-block:: bash

    pip install git+https://github.com/dnidever/spyderwebb



Dependencies
============

Here are the required packages.  Most of them can be pip installed.

- numpy
- scipy
- astropy
- matplotlib
- jwst
